package com.jeeplus.test.jobPosion.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Lists;
import com.jeeplus.aop.logging.annotation.ApiLog;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.test.jobPosion.domain.PositionCategory;
import com.jeeplus.test.jobPosion.service.PositionCategoryService;
import com.jeeplus.test.jobPosion.service.dto.PositionCategoryDTO;
import com.jeeplus.test.jobPosion.service.mapstruct.PositionCategoryWrapper;
import com.jeeplus.test.projectRecords.domain.Project;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@Api("职务分类管理")
@RestController
@RequestMapping(value = "/job/position_category")
public class PositionCategoryController {

    @Autowired
    private PositionCategoryService positionCategoryService;

    /**
     * 查询职务分类列表
     * @param positionCategory
     * @param page
     * @return
     * @throws Exception
     */
    @ApiLog("查询职务分类列表")
    @PreAuthorize("hasAuthority('job:position_category:list')")
    @GetMapping("list")
    public ResponseEntity<IPage<PositionCategory>> data(PositionCategory positionCategory, Page<PositionCategory> page) throws Exception {
        QueryWrapper<PositionCategory> queryWrapper = QueryWrapperGenerator.buildQueryCondition ( positionCategory, PositionCategory.class );
        queryWrapper.orderByDesc("create_date");
        IPage<PositionCategory> result = positionCategoryService.page (page,queryWrapper);
        return ResponseEntity.ok (result);
    }

    /**
     * 查询职务分类数据
     * @param id
     * @return
     */
    @ApiLog("查询职务分类详情")
    @PreAuthorize ("hasAnyAuthority('job:position_category:view','job:position_category:add','job:position_category:edit')")
    @GetMapping("queryById")
    public ResponseEntity queryById(@RequestParam("id") String id) {
        PositionCategory positionCategory = positionCategoryService.getById ( id );
        return ResponseEntity.ok (positionCategory);
    }

    /**
     * 添加职务分类
     * @param positionCategoryDTO
     * @return
     */
    @ApiLog("添加职务分类")
    @PreAuthorize("hasAnyAuthority('job:position_category:save','job:position_category:edit')")
    @PostMapping("save")
    public ResponseEntity save(@Valid @RequestBody PositionCategoryDTO positionCategoryDTO) {
        PositionCategory positionCategory = PositionCategoryWrapper.INSTANCE.toEntity(positionCategoryDTO);
        positionCategoryService.saveOrUpdate(positionCategory);
        return ResponseEntity.ok ("保存职务分类成功");
    }

    /**
     * 删除职务分类
     * @param ids
     * @return
     */
    @ApiLog("删除职务分类")
    @PreAuthorize ("hasAuthority('job:position_category:del')")
    @DeleteMapping("delete")
    public ResponseEntity delete(String ids) {
        String idArray[] =ids.split(",");
        positionCategoryService.removeByIds (Lists.newArrayList (idArray));
        return ResponseEntity.ok ("删除职务分类成功");
    }


}
