package com.jeeplus.test.jobPosion.controller;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Lists;
import com.jeeplus.aop.logging.annotation.ApiLog;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.test.jobPosion.domain.Position;
import com.jeeplus.test.jobPosion.domain.PositionCategory;
import com.jeeplus.test.jobPosion.service.PositionCategoryService;
import com.jeeplus.test.jobPosion.service.PositionService;
import com.jeeplus.test.jobPosion.service.dto.PositionDTO;
import com.jeeplus.test.jobPosion.service.mapstruct.PositionWrapper;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api("职务管理")
@RestController
@RequestMapping(value = "/job/position")
public class PositionController {

    @Autowired
    private PositionService positionService;

    @Autowired
    private PositionCategoryService positionCategoryService;

    /**
     * 查询职务列表
     * @param position
     * @param page
     * @return
     * @throws Exception
     */
    @ApiLog("查询职务列表")
    @PreAuthorize("hasAuthority('job:position:list')")
    @GetMapping("list")
    public ResponseEntity<IPage<Position>> data(Position position, Page<Position> page) throws Exception {
        QueryWrapper<Position> queryWrapper = QueryWrapperGenerator.buildQueryCondition ( position, Position.class );
        IPage<Position> result = positionService.findList (page,queryWrapper);
        return ResponseEntity.ok (result);
    }

    /**
     * 查询职务数据
     * @param id
     * @return
     */
    @ApiLog("查询职务详情")
    @PreAuthorize ("hasAnyAuthority('job:position:view','job:position:add','job:position:edit')")
    @GetMapping("queryById")
    public ResponseEntity queryById(@RequestParam("id") String id) {
        Position position = positionService.getById ( id );
        return ResponseEntity.ok (position);
    }

    /**
     * 查询全部职务类型
     * @return
     */
    @ApiLog("查询全部职务类型")
    @PreAuthorize ("hasAnyAuthority('job:position:view','job:position:add','job:position:edit')")
    @GetMapping("queryAllCategory")
    public ResponseEntity<List<PositionCategory>> queryAllCategory() {
        List<PositionCategory> list = positionCategoryService.list();
        return ResponseEntity.ok (list);
    }

    /**
     * 添加职务
     * @param positionDTO
     * @return
     */
    @ApiLog("添加职务")
    @PreAuthorize("hasAnyAuthority('job:position:save','job:position:edit')")
    @PostMapping("save")
    public ResponseEntity save(@Valid @RequestBody PositionDTO positionDTO) {
        Position position = PositionWrapper.INSTANCE.toEntity(positionDTO);
        positionService.saveOrUpdate(position);
        return ResponseEntity.ok ("保存职务分类成功");
    }

    /**
     * 删除职务
     * @param ids
     * @return
     */
    @ApiLog("删除职务")
    @PreAuthorize ("hasAuthority('job:position:del')")
    @DeleteMapping("delete")
    public ResponseEntity delete(String ids) {
        String idArray[] =ids.split(",");
        positionService.removeByIds (Lists.newArrayList (idArray));
        return ResponseEntity.ok ("删除职务成功");
    }


}
